ExtensionArgs

Struct ExtensionArgs 

pub struct ExtensionArgs {
    pub positional: Vec<ExtensionValue>,
    pub named: IndexMap<String, ExtensionValue>,
    pub output_columns: Vec<ExtensionColumn>,
}
Represents extension arguments plus optional output columns.

Named arguments are stored in an IndexMap whose iteration order determines display order. Extension super::Explainable::to_args() implementations should insert named arguments in the order they should appear in the text format.

Fields

positional: Vec<ExtensionValue>

Positional arguments.

named: IndexMap<String, ExtensionValue>

Named arguments, displayed in the order they were inserted

output_columns: Vec<ExtensionColumn>

Output columns for custom relation types.

Implementations

Source

impl ExtensionArgs

pub fn parse<T>(&self) -> Result<T, ExtensionError>
where T: Explainable,

Decodes these arguments as an Explainable extension value.

If decoding succeeds, this method rejects any named or positional arguments the implementation did not access. If decoding fails, it returns that error without checking for unhandled arguments.

pub fn push<T>(&mut self, value: T)
where T: Into<ExtensionValue>,

Push a positional extension argument.

pub fn insert<K, V>(&mut self, name: K, value: V) -> Option<ExtensionValue>
where K: Into<String>, V: Into<ExtensionValue>,

Insert a named extension argument, returning any previous value.