A trait for types that are parsed from a pest::iterators::Pair<Rule> that
depends on the context - e.g. extension lookups or other contextual
information. This is used for types that are not directly parsed from the
grammar, but rather require additional context to parse correctly.