pub struct OutputOptions {
pub show_extension_urns: bool,
pub show_simple_extensions: bool,
pub show_simple_extension_anchors: Visibility,
pub show_emit: bool,
pub read_types: bool,
pub literal_types: Visibility,
pub nullability: bool,
pub indent: String,
pub show_literal_binaries: bool,
pub virtual_table_multiline_threshold: usize,
}Expand description
OutputOptions holds the options for textifying a Substrait type.
Fields
show_extension_urns: boolShow the extension URNs in the output.
show_simple_extensions: boolShow the extensions in the output. By default, simple extensions are expanded into the input.
show_simple_extension_anchors: VisibilityShow the anchors of simple extensions in the output, and not just their names.
If Required, the anchor is shown for all simple extensions.
show_emit: boolInstead of showing the emitted columns inline, show the emits directly.
read_types: boolShow the types for columns in a read
literal_types: VisibilityShow the types for literals. If Required, the type is shown for anything other than
i64, fp64, boolean, or string.
nullability: boolShow the nullability of types
indent: StringThe indent to use for nested types
show_literal_binaries: boolShow the binary values for literal types as hex strings. Normally, they are shown as ‘{{binary}}’
virtual_table_multiline_threshold: usizeA Read:Virtual with at least this many rows is emitted across multiple
lines (one - row per line) instead of inline. Set to a very large
value to keep virtual tables inline regardless of row count. Defaults to 3.
Implementations
Sourceimpl OutputOptions
impl OutputOptions