Module types

Module types 

Structs

Anchor
Name
The name of a something to be represented. It will be displayed on its own if the string is a proper identifier, or in double quotes if it is not.
NamedAnchor
OutputType
The type desciptor of the output of a function call.

Functions

escaped
Escape a string for use in a literal or quoted identifier.
is_identifer
A valid identifier is a sequence of ASCII letters, digits, and underscores, starting with a letter.