Module relations

Module relations 

Structs

Column
NamedColumnList
ParsedNamedArgs
Extracts named arguments from pest pairs with duplicate detection and completeness checking.
TableName

Traits

RelationParsePair
A trait for parsing relations with full context needed for tree building. This includes extensions, the parsed pair, input children, and output field count.