Module relations

Module relations 

Structs

Column
NamedColumnList
TableName

Traits

RelationParsePair
A trait for parsing relations with full context needed for tree building. This includes extensions, the parsed pair, input children, and output field count.