Module relations
substrait_
explain
0.1.0
Module relations
Module Items
Structs
Traits
In substrait_
explain::
parser
substrait_explain
::
parser
Module
relations
Structs

Column
Named
Column
List
Table
Name
Traits

Relation
Parse
Pair
A trait for parsing relations with full context needed for tree building. This includes extensions, the parsed pair, input children, and output field count.